cgexplore.terms.TargetPairedBondRange
=====================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetPairedBondRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetPairedBondRange.yield_bonds
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetPairedBondRange.type1s
      ~TargetPairedBondRange.type2s
      ~TargetPairedBondRange.element1s
      ~TargetPairedBondRange.element2s
      ~TargetPairedBondRange.bond_rs
      ~TargetPairedBondRange.bond_ks
   
   